@@ -15,11 +15,11 @@ Params::Validate::Strict - Validates a set of parameters against a schema
 
 =head1 VERSION
 
-Version 0.06
+Version 0.07
 
 =cut
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 =head1 SYNOPSIS
 
@@ -171,6 +171,12 @@ sub validate_strict
 			$rules = { type => $rules };
 		}
 
+		if((my $min = $rules->{'min'}) && (my $max = $rules->{'max'})) {
+			if($min > $max) {
+				croak(__PACKAGE__, "::validate_strict($key): min must be <= max ($min > $max)");
+			}
+		}
+
 		# Validate based on rules
 		if(ref($rules) eq 'HASH') {
 			foreach my $rule_name (keys %$rules) {
